@@ -42,9 +42,9 @@ copyright = '2010, Ben Bangert, Mike Orr'
 # other places throughout the built documents.
 #
 # The short X.Y version.
-version = '1.12'
+version = '1.12.1'
 # The full version, including alpha/beta/rc tags.
-release = '1.12'
+release = '1.12.1'
 
 # There are two options for replacing |today|: either, you set today to some
 # non-false value, then it is used:
